@@ -16,18 +16,6 @@ from migrator.models import MigratedObject
 from migrator.exceptions import MigrationError
 
 
-def ask_yesno_question(question, default_answer):
-    while True:
-        prompt = '%s: (yes/no) [%s]: ' % (question, default_answer)
-        answer = raw_input(prompt).strip()
-        if answer == '':
-            return default_answer
-        elif answer in ('yes', 'no'):
-            return answer
-        else:
-            print 'Please answer yes or no'
-
-
 class MigrationCommand(BaseCommand):
 
     MODE_DEFAULT = 'abortifempty'
@@ -51,19 +39,35 @@ class MigrationCommand(BaseCommand):
                     help='Migrate only new objects (not migrated in previous migrations)'),
             make_option('-a', '--all', action='store_true', default=False, dest='all_objects',
                     help='Migrate all objects including news'),
+            make_option('-o', '--no-interactive', action='store_true', default=False, dest='no_interactive',
+                    help='Tells Django to NOT prompt the user for input of any kind.'),
     )
 
     def _log(self, msg, verbosity):
         if self.verbosity >= verbosity:
             print msg
 
+    def ask_yesno_question(self, question, default_answer='no'):
+        if self.no_interactive:
+            return default_answer
+        while True:
+            prompt = '%s: (yes/no) [%s]: ' % (question, default_answer)
+            answer = raw_input(prompt).strip()
+            if answer == '':
+                return default_answer
+            elif answer in ('yes', 'no'):
+                return answer
+            else:
+                print 'Please answer yes or no'
+
+    def _check_previous_migrations_question(self):
+        return self.ask_yesno_question(
+                    'There is half migrated objects in this database, do you want to continue?')
+
     def _check_previous_migrations(self):
         not_finished_migrations = MigratedObject.objects.filter(is_migrating=True)
         if not_finished_migrations:
-            answer = ask_yesno_question(
-                'There is half migrated objects in this database, do you want to continue?',
-                'no',
-            )
+            answer = self._check_previous_migrations_question()
             if answer == 'no':
                 self.info('Migration aborted')
                 sys.exit(1)
@@ -86,6 +90,7 @@ class MigrationCommand(BaseCommand):
         self.only_with_errors = options.get('only_with_errors')
         self.only_new_objects = options.get('only_new_objects')
         self.all_objects = options.get('all_objects')
+        self.no_interactive = options.get('no_interactive')
         if options.get('from_date'):
             self.from_date = datetime(*time.strptime(options.get('from_date'), '%Y-%m-%d')[:3])
         else:
